
.. _standard-macro-catalog:

=======================
Standard macro catalog
=======================

.. hlist::
    :columns: 5

    * :class:`~sardana.macroserver.macros.standard.wa`
    * :class:`~sardana.macroserver.macros.standard.wm`
    * :class:`~sardana.macroserver.macros.standard.pwa`
    * :class:`~sardana.macroserver.macros.standard.pwm`
    * :class:`~sardana.macroserver.macros.standard.set_lim`
    * :class:`~sardana.macroserver.macros.standard.set_lm`
    * :class:`~sardana.macroserver.macros.standard.set_pos`
    * :class:`~sardana.macroserver.macros.standard.mv`
    * :class:`~sardana.macroserver.macros.standard.umv`
    * :class:`~sardana.macroserver.macros.standard.mvr`
    * :class:`~sardana.macroserver.macros.standard.umvr`
    * :class:`~sardana.macroserver.macros.standard.ct`
    * :class:`~sardana.macroserver.macros.standard.uct`
    * :class:`~sardana.macroserver.macros.standard.settimer`

    * :class:`~sardana.macroserver.macros.env.lsenv`
    * :class:`~sardana.macroserver.macros.env.senv`
    * :class:`~sardana.macroserver.macros.env.usenv`
    * :class:`~sardana.macroserver.macros.env.dumpenv`

    * :class:`~sardana.macroserver.macros.lists.lsa`
    * :class:`~sardana.macroserver.macros.lists.lsm`
    * :class:`~sardana.macroserver.macros.lists.lspm`
    * :class:`~sardana.macroserver.macros.lists.lsexp`
    * :class:`~sardana.macroserver.macros.lists.lsior`
    * :class:`~sardana.macroserver.macros.lists.lsmeas`
    * :class:`~sardana.macroserver.macros.lists.lsct`
    * :class:`~sardana.macroserver.macros.lists.ls0d`
    * :class:`~sardana.macroserver.macros.lists.ls1d`
    * :class:`~sardana.macroserver.macros.lists.ls2d`
    * :class:`~sardana.macroserver.macros.lists.lspc`
    * :class:`~sardana.macroserver.macros.lists.lsctrl`
    * :class:`~sardana.macroserver.macros.lists.lspc`
    * :class:`~sardana.macroserver.macros.lists.lsi`
    * :class:`~sardana.macroserver.macros.lists.lsctrllib`
    * :class:`~sardana.macroserver.macros.lists.lsa`

    * :class:`~sardana.macroserver.macros.expert.lsmac`
    * :class:`~sardana.macroserver.macros.expert.defmeas`
    * :class:`~sardana.macroserver.macros.expert.udefmeas`
    * :class:`~sardana.macroserver.macros.expert.defelem`
    * :class:`~sardana.macroserver.macros.expert.udefelem`
    * :class:`~sardana.macroserver.macros.expert.defctrl`
    * :class:`~sardana.macroserver.macros.expert.udefctrl`
    * :class:`~sardana.macroserver.macros.expert.prdef`
    * :class:`~sardana.macroserver.macros.expert.relmac`
    * :class:`~sardana.macroserver.macros.expert.relmaclib`

    * :class:`~sardana.macroserver.macros.scan.ascan`
    * :class:`~sardana.macroserver.macros.scan.a2scan`
    * :class:`~sardana.macroserver.macros.scan.a3scan`
    * :class:`~sardana.macroserver.macros.scan.a4scan`
    * :class:`~sardana.macroserver.macros.scan.amultiscan`
    * :class:`~sardana.macroserver.macros.scan.dscan`
    * :class:`~sardana.macroserver.macros.scan.d2scan`
    * :class:`~sardana.macroserver.macros.scan.d3scan`
    * :class:`~sardana.macroserver.macros.scan.d4scan`
    * :class:`~sardana.macroserver.macros.scan.dmultiscan`
    * :class:`~sardana.macroserver.macros.scan.mesh`
    * :class:`~sardana.macroserver.macros.scan.fscan`
    * :class:`~sardana.macroserver.macros.scan.scanhist`
